##############
pyannote.audio
##############

`pyannote.audio` is an open-source Python library that provides neural building blocks for speaker diarization.

Installation
============

::

  $ conda create -n pyannote python=3.10
  $ conda activate pyannote
  $ pip install pyannote.audio


API documentation
=================

.. toctree::
   :maxdepth: 2
